---
title: "What is Decentralized Identity? and Digital ID Fundamentals."
permalink: /getting-started/
toc: false
last_modified_at: 2020-11-02

---

<center><img src="https://i.imgur.com/9KpJRDr.png"/></center>

<h2>What is Decentralized ID?</h2>

The essence of Decentralized-ID is in creating open standards for a privacy preserving internet-wide identity layer — not owned by any one particular organization, but interoperable between all.

It's impossible to have a conversation about decentralized-id without discussing blockchain, self sovereign identity, standardization and frameworks, along with global privacy and digital identifiction regulations:

<ul>
  <li>Cryptographers, privacy advocates and digital identity enthusiasts <a href="/history/">laid the foundation</a> by deeply considering the privacy implications of identification practices in the electronic world.</li>
  <ul><li><a href="/literature/self-sovereign-identity/evolution-of-ssi/">Self Sovereign Identity principles emerged</a> from their work, gathering momentum as the digital age began to settle in.</li></ul>
  <li>The European Union's GDPR enlarged the global conversation around digital privacy practices, lending much weight to the SSI credo.</li>
  <li>The United Nations Sustainable Development Goals (SDGs) have also fueled efforts towards a global and widely accessible identity solution.</li>
  <li>Satoshi Nakamoto released <a href="https://bitcoinfo.xyz">Bitcoin</a>, proving the concept of digital scarcity in the form of a decentralized peer-to-peer (P2P) currency, inspiring leaders in every industry to integrate it's features to their business models.</li>
  <li>At the same time, <a href="https://sourcecrypto.pub/decentralized-web/">Decentralized web</a> and P2P technologists have also lent strength to Decentralized Identity efforts.</li>
  <li>Collectively arrived at solutions are trending towards congruence with the spirit of innovation, privacy concerns, and compliance within the evolving global regulatory landscape.</li>
</ul>

<h2>Getting Started with Decentralized ID</h2>

<ul>
  <li><a href="http://www.windley.com/archives/2019/01/the_laws_of_identity.shtml">The Laws of Identity</a></li>
    <blockquote>The Internet was created without any way to identify the people who used it. The Internet was a network of machines. Consequently, all the identity in Internet protocols is designed to identify machines and services. People used the Internet through some institution (their company or university) and were part of that institution's administrative identity system. This can still be seen in the format of email addresses that identify both recipient and sender as someone@someplace. As the Internet grew to include people who weren't formally associated with an institution, every Web site and service created their own administrative identity domains. The result is the fractured plethora of identifiers, policies, and user experiences that constitute digital identity in 2019.</blockquote>
  <li><a href="https://raw.githubusercontent.com/jandrieu/rebooting-the-web-of-trust-fall2016/master/topics-and-advance-readings/a-technology-free-definition-of-self-sovereign-identity.pdf) - A topic paper by Joe Andrieu (joe@joeandrieu.com">A Technology‐Free Definition of Self‐Sovereign Identity</a> for the third Rebooting Web of Trust DesignShop October 2016</li>
    <blockquote>Abstract The desire for increased control over our identity has catapulted the idea of “self‐sovereign identity” into the forefront of digital identity innovation, yet the term lacks a rigorous definition beyond specific technical implementations1. This paper explores what self‐sovereign identity means independent of technology: what people need from independent identity capabilities. I want to understand how such a system enables both individuals whose identities are in play (subjects), as well as those who use those “identities” to correlate interactions across contexts (observers). I start with grounding individual sovereignty in the Enlightenment and identity in its core function of correlation, then propose core characteristics of a self‐sovereign identity system. My eventual goal is to model the technology‐independent requirements of a self‐sovereign solution suitable for realizing UN Sustainable Development Goal 16.9: “Providing every last person on the planet with a legal identity by 2030.”</blockquote>
  <li><a href="https://www.windley.com/archives/2017/08/the_case_for_decentralized_identity.shtml">The Case for Decentralized Identity</a></li>
    <blockquote>We cannot decentralize many interesting systems without also decentralizing the identity systems upon which they rely. We're finally in a position to create truly decentralized systems for digital identity.</blockquote>
</ul>

<div class="side">
  <a class="twitter-timeline" data-width="350" data-link-color="#1DA1F2" data-dnt="true" data-border-color="#657786" href="https://twitter.com/DecentralizeID/timelines/1322735918386733057?ref_src=twsrc%5Etfw">Self Sovereign ID 101 - Curated tweets by DecentralizeID</a> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>
</div>

<blockquote class="twitter-tweet" data-partner="tweetdeck"><p lang="en" data-link-color="#1DA1F2" data-border-color="#657786" dir="ltr">The evolution of online identity:<br><br>1. Siloed Identity: All services hold your data.<br><br>2. Federated Identity: Brokers hold your data.<br><br>3. Self-Sovereign Identity: You hold your data.</p>&mdash; Tykn (@Tykn_tech) <a href="https://twitter.com/Tykn_tech/status/1321108291305558016?ref_src=twsrc%5Etfw">October 27, 2020</a></blockquote>

<ul>
  <li><a href="https://github.com/ChristopherA/self-sovereign-identity/blob/master/ThePathToSelf-SovereignIdentity.md">The Path to Self-Sovereign Identity</a></li>
    <blockquote>Self-sovereign identity is the next step beyond user-centric identity and that means it begins at the same place: the user must be central to the administration of identity. That requires not just the interoperability of a user’s identity across multiple locations, with the user’s consent, but also true user control of that digital identity, creating user autonomy. To accomplish this, a self-sovereign identity must be transportable; it can’t be locked down to one site or locale.</blockquote>
  <li><a href="https://sovrin.org/wp-content/uploads/2018/03/The-Inevitable-Rise-of-Self-Sovereign-Identity.pdf">The Inevitable Rise of Self-Sovereign Identity</a></li>
    <blockquote>This lack of secure, portable, user-controlled identity has some dire consequences. It means that a person’s identity and personal data only exists within the context of each specific website or application he or she uses. Stop using the site or application and the person’s digital existence is meaningless. And a user’s control over their identity and data must be exerted on a site-by-site, app-by-app basis.</blockquote>
  <li><a href="https://id2020.org/digital-identity">The Need for Good Digital ID is Universal</a></li>
    <blockquote>The ability to prove who you are is a fundamental and universal human right. Because we live in a digital era, we need a trusted and reliable way to do that both in the physical world and online.</blockquote>
  <li><a href="https://medium.com/decentralized-identity/the-rising-tide-of-decentralized-identity-2e163e4ec663">The Rising Tide of Decentralized Identity</a> - Decentralized Identity Foundation</li>
    <blockquote>Creating a unified decentralized identity ecosystem requires addressing a set of fundamental user needs and technical challenges:<br><br>
    - Enabling registration of self-sovereign identifiers that no provider owns or controls.<br>
    - The ability to lookup and discover identifiers and data across decentralized systems.<br>
    - Providing a mechanism for users to securely store sensitive identity data, and enabling them to precisely control what is shared with others.</blockquote>
</ul>

<style>.embed-container { position: relative; padding-bottom: 56.25%; height: 0; overflow: hidden; max-width: 100%; } .embed-container iframe, .embed-container object, .embed-container embed { position: absolute; top: 0; left: 0; width: 100%; height: 100%; }</style><div class='embed-container'><iframe src='https://www.youtube.com/embed/DaM0UtQTLCs' frameborder='0' allowfullscreen></iframe></div>

<h2>More on Decentralized | Self Sovereign Identity</h2>

<ul>
  <li><em><a href="https://decentralized-id.com/literature/">Literature</a></em></li>
  <li><em><a href="https://decentralized-id.com/literature/self-sovereign-identity/">Self Sovereign Identity</a></em></li>
</ul>

<h2>Digital Identity 101</h2>

If you're looking to freshen up on your digital identity fundamentals, the following resources will be a good place to start.

<ul>
  <li><a href="https://medium.com/@dip_ak/guide-to-digital-identity-part-1-4b7c8fe45ee1">Guide to Digital Identity — Part 1</a> - Deepak Gupta</li>
    <blockquote>Are you curious about the Digital Identity Ecosystem? If you have been looking for a good, reliable and easy-to-understand source of information and haven’t had any luck, then this article is for you.</blockquote>
  <li><a href="https://medium.com/humanizing-the-singularity/what-is-digital-identity-c77983c03306">What is Digital Identity?</a></li>
    <blockquote>The Sapir–Whorf Hypothesis, also known as the principle of linguistic relativity, posits that language constructs our reality and worldview. While the hypothesis has been contested over the years, language is unarguably fundamental to the models of the world we build in our heads — and in our systems.</blockquote>
  <li><a href="https://www.beyondtrust.com/blog/entry/understanding-authentication-vs-authorization">Difference Between Authentication and Authorization</a></li>
    <blockquote>What is the difference between authentication (authN) versus authorization (authZ)? While these two fundamental security terms are often confused with each other, the only real similarity is they both begin with the letter “A” and are linked by an account. In concept, one verifies the account (authentication) and the other sanctions (authorization) the account to perform a task. Because these terms are so fundamental, it’s crucial to understand the difference between them, and the implications for each when the concepts are blended</blockquote>
  <li><a href="https://www.beyondtrust.com/blog/entry/what-is-identity-and-access-management-and-why-is-it-a-vital-it-security-layer">What is Identity and Access Management and Why is it a Vital IT Security Layer?</a></li>
    <blockquote>Identity and Access Management (IAM), also called identity management, refers to the IT security discipline, framework, and solutions for managing digital identities. Identity management encompasses the provisioning and de-provisioning of identities, securing and authentication of identities, and the authorization to access resources and/or perform certain actions. While a person (user) has only one singular digital identity, they may have many different accounts representing them. Each account can have different access controls, both per resource and per context.</blockquote>
</ul>

<h3>Video</h3>

* <a href="https://idpro.org/member-present">IDPro Member Presentations - Identiverse 2019</a> - <a href="https://www.youtube.com/playlist?list=PLpKq7xRiIHaTDwAqpIU1UYpKZY03tfTMf">playlist</a> 
  * <a href="https://www.youtube.com/watch?v=T5w1EXqMqR0&list=PLpKq7xRiIHaTDwAqpIU1UYpKZY03tfTMf">2019 - Introduction to Identity Part 1 - Identiverse</a>
    > This workshop — provided by IDPro — will provide a comprehensive (and fun) introductory view of the identity world that will give participants a solid understanding of IAM’s foundations. Part 1 of this 2-part class begins with the basics like directories, identity proofing, provisioning, authentication (including multi-factor), authorization, as well as federation technologies like SAML, OAuth, and OpenID Connect. In Part 2, we build on those foundational technologies to explain PKI & digital certificates, privileged access management, identity for IoT, identity assurance, privacy issues, identity standards organizations, and even known attack vectors.
  * <a href="https://www.youtube.com/watch?v=zxKRUXmTLJs">Introduction to Identity Part 2 - June 25 - Identiverse 2019</a>
  * <a href="https://www.youtube.com/watch?v=kWpqFWz_9II">Modern Identity for Developers 101 - June 25 - Identiverse 2019</a>
    > Modern identity promises to solve some of the thorniest problems that historically plagued handling authentication and access control in applications. That sounds great in theory, but how do thinks really look like when the rubber hits the road – what does it take to incorporate modern identity in your applications development practice? Come to this session to learn the basis of modern identity development and be better equipped to understand and participate to the session in this year’s Identiverse development track.
  * <a href="https://www.youtube.com/watch?v=25qiVyZEZOg&list=PLpKq7xRiIHaTDwAqpIU1UYpKZY03tfTMf&index=18">An Introduction to Mobile Identity - June 25 - Identiverse 2019</a>


<h2>Glossaries</h2>

<ul>
  <li><a href="http://wiki.idcommons.org/Lexicon">IDCommongs - Lexicon</a></li>
  <li><a href="http://wiki.idcommons.org/Identipedia">Identipedia</a></li>
  <li><a href="http://wiki.idcommons.org/Systemic_Elements">Systemic Elements</a></li>
</ul>

<h2>Resources</h2>

<ul>
  <li><a href="http://ssimeetup.org/">SSI Meetup</a> [<a href="https://www.slideshare.net/SSIMeetup/presentations/">**ϟ**</a>] [<a href="https://www.youtube.com/channel/UCSqSTlKdbbCM1muGOhDa3Og">**V**</a>]</li>
  <li><a href="https://iiw.idcommons.net/Main_Page">IIW-Wiki</a></li>
  <li><a href="http://wiki.idcommons.net/Main_Page">wiki.idcommons.net</a></li>
  <li><a href="https://github.com/WebOfTrustInfo/">WebOfTrustInfo</a></li>
  <li><a href="https://github.com/peacekeeper/blockchain-identity">peacekeeper/blockchain-identity</a></li>
  <li><a href="https://identitywoman.net/">identitywoman.net</a></li>
  <li><a href="http://www.windley.com/tags/identity.shtml">windley.com/tags/identity</a></li>
  <li><a href="https://identityblog.com">Kim Camerons Identity Blog</a></li>
  <li><a href="https://github.com/karimStekelenburg/awesome-self-sovereign-identity">karimStekelenburg/awesome-self-sovereign-identity</a></li>
</ul>

---

<h3>Next – History</h3>

<em>Check out our <a href="https://decentralized-id.com/history">history section for additional background info</a> on the decades-long quest for decentralized identity.</em>