---
date: 2019-03-11
title: Bitcoin Identity Standards and Applications
excerpt: > 
  The Bitcoin Reference DID method (did:btcr) supports DIDs on the public Bitcoin blockchain. The Bitcoin Reference method has minimal design goals: a DID trust anchor based on the Bitcoin blockchain, updates publicly visible and auditable via Bitcoin transactions, and optionally, additional DID Document information referenced in the transaction OP_RETURN data field.
layout: single
classes: wide
toc: false
header:
  image: /images/btcr-header.png
  teaser: /images/bitcoin-1813503_madartzgraphics.png
permalink: blockchain/bitcoin/
canonical_url: 'https://decentralized-id.com/blockchain/bitcoin/'
redirect_from: 
  - blockchain/bitcoin
  - id-initiatives/bitcoin/
  - id-initiatives/bitcoin
categories: ["Blockchain"]
tags: ["Bitcoin","Microsoft","ION","BTCR","XDI"]
last_modified_at: 2020-01-07

---

![](https://i.imgur.com/q32lAXY.png)

[Panel Discussion on Decentralized Identity at Bitcoin Wednesday](https://www.youtube.com/watch?v=TQqu0bLLXSY)
  > This excellent panel discussion on decentralized identity capped off an evening of presentations during Bitcoin Wednesday held at the Volkshotel in Amsterdam on 7 November, 2018.
  > - Martin Riedel of Civic,
  > - Orfeas Litos of the University of Edinburgh,
  > - Moritz Neto of Tenzorum,
  > - Michael Mainelli of Z/Yen and
  > - Eric Tang of LivePeer.

## Early History in using Bitcoin for Digital Identity

* [Identity protocol v1](https://en.bitcoin.it/wiki/Identity_protocol_v1) - bitcoin wiki
* [Bitnation taps Blockchain tech to aid Refugees](https://www.newsbtc.com/2015/09/09/bitnation-taps-blockchain-tech-to-aid-refugees/)

## BTCR 

[BTCR Project - OKim's Razor](https://www.okimsrazor.com/project/btcr-project/)
  > BTCR is a Decentralized Identifier (DID) method specification based on the bitcoin blockchain. I helped develop the initial versions of the BTCR method specification and implementations.
  > 
  > It’s completely open source, so you can experiment with the BTCR playground (which demonstrates BTCR DID lookup and creation), supporting libraries, and specifications around resolving BTCR DIDs. This is a community effort, and if you’d like to be involved, please let me know (@kimdhamilton on twitter).
[BTCR DID Method Updates](https://medium.com/@kimdhamilton/btcr-did-method-updates-d0fd14386139) by Kim Hamilton Duffy
  > The Bitcoin Reference DID method (did:btcr) is designed as a minimal, secure, and open Decentralized Identifier (DID) method anchored to the Bitcoin blockchain. DIDs are an interoperable locator for identity that does not require permission from anyone else. The BTCR method specifically is fully open source — not tied to a commercial vendor — which makes it a valuable vendor-agnostic demonstration of the emerging DID specification.

[![](/images/btcr.png)](https://slideplayer.com/slide/15397169/)


* [BTCR DID Method](https://w3c-ccg.github.io/didm-btcr/) - [source](https://github.com/w3c-ccg/didm-btcr) - WORK ITEM: BTCR DID Method Spec did:btcr:      
  * The Bitcoin Reference DID method (did:btcr) supports DIDs on the public Bitcoin blockchain. The Bitcoin Reference method has minimal design goals: a DID trust anchor based on the Bitcoin blockchain, updates publicly visible and auditable via Bitcoin transactions, and optionally, additional DID Document information referenced in the transaction OP_RETURN data field. No other Personal Identifiable Information (PII) would be placed on the immutable blockchain.
* [BTCR DID Resolver Specification](https://nbviewer.jupyter.org/github/WebOfTrustInfo/rebooting-the-web-of-trust-spring2018/blob/master/final-documents/btcr-resolver.pdf)
  > This describes the process of resolving a BTCR DID into a DID Document. The draft reference implementation is available at [https://github.com/WebOfTrustInfo/btcr-did-tools-js](https://github.com/WebOfTrustInfo/btcr-did-tools-js) (see didFormatter.js). Note not all steps described in this document are implemented yet.
  > 
  > See the [BTCR playground](https://weboftrustinfo.github.io/btcr-tx-playground.github.io/) for a live demonstration. The BTCR playground uses the draft reference implementation BTCR DID resolver.
* [BTCR DID Method](https://w3c-ccg.github.io/didm-btcr/) 
  > The Bitcoin Reference DID method (did:btcr) supports DIDs on the public Bitcoin blockchain. The Bitcoin Reference method has minimal design goals: a DID trust anchor based on the Bitcoin blockchain, updates publicly visible and auditable via Bitcoin transactions, and optionally, additional DID Document information referenced in the transaction OP_RETURN data field. No other Personal Identifiable Information (PII) would be placed on the immutable blockchain.
  * [btcr tx conversion playground](https://weboftrustinfo.github.io/btcr-tx-playground.github.io/) 
* [WebOfTrustInfo/btcr-tx-playground.github.io](https://github.com/WebOfTrustInfo/btcr-tx-playground.github.io)
* [WebOfTrustInfo/btcr-did-tools-js](https://github.com/WebOfTrustInfo/btcr-did-tools-js)
* [WebOfTrustInfo/btcr-hackathon](https://github.com/WebOfTrustInfo/btcr-hackathon) - Virtual hackathon to create spec and code for Bitcoin-based Decentralized Identifiers (DIDs)
* [BTCR v0.1 Decisions](https://github.com/WebOfTrustInfo/rwot7-toronto/blob/master/final-documents/btcr_0_1.pdf) by Kim Hamilton Duffy, Christopher Allen, Dan Pape (01/19)
  > The Bitcoin Reference (BTCR) DID method supports DIDs using the Bitcoin blockchain. This method has been under development through Rebooting Web of Trust events and hackathons over the past year. The BTCR method's reliance on the Bitcoin blockchain presents both advantages and design challenges. During RWOT7, the authors made a number of design and implementation decisions -- largely scope-cutting in nature -- in order to lock down a Minimum Viable Product (MVP) version, which we'll refer to as v0.1. This paper documents those decisions, which will apply to the upcoming v0.1 BTCR method specification and associated v0.1 BTCR reference implementation.
* [DIDs Demystified: A hands-on intro to DIDs via the BTCR DID Method – Kim Hamilton Duffy – Webinar 5](https://ssimeetup.org/dids-demystified-hands-intro-dids-btcr-did-method-kim-hamilton-duffy-webinar-5/)
  > This talk will demystify Decentralized Identifiers (DIDs) via the simple Bitcoin Reference (BTCR) DID Method. Kim will introduce the basics of DIDs and show how they work in action through demos of the creation/updating and resolution process in BTCR. We’ll build on this knowledge by discussing advanced features enabled by DIDs, along with a brief survey of other DID methods. By the end of the talk, you’ll be able to create and resolve your own BTCR DIDs through the live BTCR playground.
* [First XDI Link Contract between "btcr" DID and "sov" DID](https://github.com/WebOfTrustInfo/rwot5-boston/tree/master/topics-and-advance-readings/first-xdi-link-contract-between-btcr-did-and-sov-did.md) by Markus Sabadello

<center><iframe src="//www.slideshare.net/slideshow/embed_code/key/B2YIOdRYlqiiPd" width="595" height="485" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="border:1px solid #CCC; border-width:1px; margin-bottom:5px; max-width: 100%;" allowfullscreen></iframe></center>
<a href="https://www.slideshare.net/SSIMeetup/dids-demystified-a-handson-intro-to-dids-via-the-bitcoin-reference-btcr-did-method" title="DIDs Demystified: A hands-on intro to DIDs via the Bitcoin Reference (BTCR) DID Method" target="_blank">DIDs Demystified: A hands-on intro to DIDs via the Bitcoin Reference (BTCR) DID Method</a>

## ION

[Microsoft is launching the first decentralized infrastructure implementation by a major tech company that is built directly on the bitcoin blockchain.](https://www.coindesk.com/microsoft-launches-decentralized-identity-tool-on-bitcoin-blockchain)
  > “To have Microsoft say they are not scared of bitcoin, and in fact, it has some very good properties and we are willing to take advantage of those properties, is, I think, a step in the right direction.”

<center><iframe src="//www.slideshare.net/slideshow/embed_code/key/e4v6fZdFL5fdu3" width="595" height="485" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="border:1px solid #CCC; border-width:1px; margin-bottom:5px; max-width: 100%;" allowfullscreen> </iframe></center>

[Introduction to Ion – a layer 2 network for Decentralized Identifiers with Bitcoin - Daniel Buchner](https://ssimeetup.org/introduction-ion-layer-2-network-decentralized-identifiers-bitcoin-daniel-buchner-webinar-29/) - [Video](https://www.youtube.com/watch?v=agPVWVe0p3Q) 

* [Toward scalable decentralized identifier systems](https://techcommunity.microsoft.com/t5/azure-active-directory-identity/toward-scalable-decentralized-identifier-systems/ba-p/560168) (ION ANN)
  > Today’s post is the next step in realizing our vision for the future of decentralized identities, [which we laid out last year](https://www.microsoft.com/en-us/microsoft-365/blog/2018/02/12/decentralized-digital-identities-and-blockchain-the-future-as-we-see-it/). We believe every person needs a decentralized, digital identity they own and control, backed by self-owned identifiers that enable secure, privacy preserving interactions. This self-owned identity must seamlessly integrate into their lives and put them at the center of everything they do in the digital world.
* [Decentralized Identity - Own and control your identity](https://query.prod.cms.rt.microsoft.com/cms/api/am/binary/RE2DjfY) - Microsoft Identity Whitepaper
* [decentralized-identity/ion](https://github.com/decentralized-identity/ion)
* [Aries and ION: Two Different Perspectives of Decentralized Identity in Blockchain Applications](https://medium.com/hackernoon/aries-and-ion-two-different-perspectives-of-decentralized-identity-in-blockchain-applications-c80dbe0bb241)

<iframe src="https://castbox.fm/app/castbox/player/id1098037/id155192208?v=8.3.0&autoplay=0" frameborder="0" width="100%" height="500"></iframe>

{% include video id="agPVWVe0p3Q" provider="youtube" %}

## Spidchain

[Spidchain](http://www.spidchain.com/) 
[Whitepaper](https://drive.google.com/file/d/0B89WE3IIHmy1Z0ZSSWVmVEtaaG8/view)
  * "offers a platform for self-sovereign identity, including desktop and mobile apps for end-users. It uses Decentralized Identifiers (DIDs) - backed by optionally Bitcoin or Ethereum - to implement a marketplace for verifiable claims. The Spidchain applications allow individuals to create, recover, and revoke DIDs, to authenticate, to sign and verify files and claims, and more."
   
### Spidchain Bitcoin Repos
* [SpidChain/spidchain-btcr](https://github.com/SpidChain/spidchain-btcr) - An implementation of the btcr standard for self sovereign distributed digital identity
* [SpidChain/electrumx](https://github.com/SpidChain/electrumx) Forked from kyuupichan/electrumx
  - Alternative implementation of spesmilo/electrum-server
* [SpidChain/btcr-spv](https://github.com/SpidChain/btcr-spv) - Poc of an SPV implementation of BTCR
* [SpidChain/satoshis-wheel-of-fortune](https://github.com/SpidChain/satoshis-wheel-of-fortune) - Pick a name from a list randomly in a provably honest way
* [SpidChain/txref-conversion-js](https://github.com/SpidChain/txref-conversion-js) - Forked from [WebOfTrustInfo/txref-conversion-js](https://github.com/WebOfTrustInfo/txref-conversion-js)
  - Javascript library for converting txids to txrefs and back


