---
date: 2019-03-05
title       : "Ethereum Identity Specs and Apps"
description : "Ethereum-based Decentralized Identity Specs, Literature, (d)Apps, and GitHub Repositories."
excerpt : "Ethereum-based Decentralized Identity Specs, Literature, (d)Apps, and GitHub Repositories."
header:
  image: "/images/ethereum-header.png"
  teaser: /images/ethereum-thumb.png
layout: single
author_profile: false
permalink: /blockchain/ethereum/
canonical_url: 'https://decentralized-id.com/blockchain/ethereum/'
redirect_from: 
  - id-initiatives/ethereum
  - id-initiatives/ethereum/
  - ethereum.html
  - ethereum/
categories: ["Blockchain","Decentralized Identity Foundation"]
tags: ["Ethereum","Jolocom","Transmute","uPort","3box"]
last_modified_at: 2020-11-05

---

[Blockchain Use Cases - Consensys](https://consensys.net/blockchain-use-cases/digital-identity/)

> The traditional identity systems of today are fragmented, insecure, and exclusive. Blockchain enables more secure management and storage of digital identities by providing unified, interoperable, and tamper-proof infrastructure with key benefits to enterprises, users, and IoT management systems.

> - How does identity work today?
> - Why do we need blockchain for identity?
> - How do decentralized digital identities work on Ethereum?
> - What are the use cases of blockchain in identity management?
> - What are the benefits of decentralized identity?


[On-Demand: Credential Management for Government and Enterprise on Blockchain](https://pages.consensys.net/credential-management-for-government-and-enterprise) - The future of access controls and credential management on Blockchain

> Security and identity are complex and ever-evolving issues for enterprise and government systems alike. Blockchain-based solutions are providing exceptional utility in solving issues of identity and digital systems. This webinar—titled Credential Management for Government and Enterprise—offers a high-level overview of where identity management is today, how we got here, and how we can transition to the next stage and beyond while making sure we leverage existing architecture and infrastructure.

## Ethereum Enterprise Alliance

- [World’s Largest Blockchain Initiative Launches Three Working Groups](https://entethalliance.org/worlds-largest-blockchain-initiative-launches-three-working-groups/)
  > NEW YORK, N.Y., USA – December 19, 2017 ––The Enterprise Ethereum Alliance (EEA), the world’s largest open-source blockchain initiative, launched today three new member-driven working groups in digital identity, energy and multiplatform interoperability. 

- [Enterprise Ethereum Alliance - Enterprise EthereumClient Specification V215 October 2018](https://entethalliance.org/wp-content/uploads/2018/11/EEA_Enterprise_Ethereum_Client_Specification_V2.pdf)
  > The Infrastructure Contracts and Standards sublayer shows emerging standards outside theEnterprise Ethereum core specification. The components in this layer provide enablers for the applications built on top of them.Role Based Access Control (RBAC) defines methods for authentication and restricting system access to authorized users, potentially realized through smart contracts.Network Governance methods control which entities can join the network and hence assist withsafeguarding exchanges.Token standards provide common interfaces and methods along with best practices. These include[ERC-20], [ERC-223], [ERC-621], [ERC-721], and [ERC-827].

- [Enterprise Ethereum Alliance Permissioned Blockchains Specification v2](https://entethalliance.github.io/client-spec/chainspec.html) EEA Editor's Draft 01 November 2020
  > This document, the Enterprise Ethereum Blockchain Specification, defines requirements for Enterprise Ethereum blockchains to ensure they can be processed interoperably by Enterprise Ethereum clients that conform to the Enterprise Ethereum Client specification [EEA-client]. Its primary intended audience is operators of Enterprise Ethereum blockchains.\
  > [...]\
  > **Credential Management Sublayer**\
  > Credentials, in the context of Enterprise Ethereum blockchains, refer to an individual’s cryptographic private keys, which are associated with that user’s Ethereum account.\
  > [...]\
  > This section presents a smart contract based registry, to provide on-chain validation that a particular Ethereum accounts or nodes is owned by a participating organization in an Enterprise Ethereum blockchain.\
  > [...]\
  > An Organization Registry follows the design outlined below.\
  > ORGIDS-300: Enterprise Ethereum Blockchains MAY implement a smart contract based Organization Registry that provides cryptographic bindings between Ethereum accounts and their owning organization with identity proofs. 

![](/images/EEA-orgs.png)



## ERC-EIP

Identity related ERC-EIP

* [ERC: Lightweight Identity #1056](https://github.com/ethereum/EIPs/issues/1056)   
  > This ERC describes a standard for creating and updating identities with a limited use of blockchain resources. An identity can have an unlimited number of delegates and attributes associated with it. Identity creation is as simple as creating a regular key pair ethereum account, which means that it's fee (no gas costs) and all ethereum accounts are valid identities. Furthermore this ERC is fully DID compliant.
* [ERC1056 ❤ ERC780 — an open identity and claims protocol for Ethereum](https://medium.com/uport/erc1056-erc780-an-open-identity-and-claims-protocol-for-ethereum-aef7207bc744)
* [EIP-780 Ethereum Claims Registry](https://github.com/ethereum/EIPs/issues/780)
* [EIP712](https://github.com/ethereum/EIPs/blob/f29527ab39357548b06b29e937a48f06ae099de7/EIPS/eip-712.md) - This is a standard for hashing and signing of typed structured data
* [ERC-1484 Digital Identity Aggregator](https://github.com/ethereum/EIPs/issues/1495) —A protocol for aggregating digital identity information that's broadly interoperable with existing, proposed, and hypothetical future digital identity standards.
* [EIP-1078](https://github.com/ethereum/EIPs/blob/ed621645c8f3bc5756492f327cda015f35d9f8da/EIPS/eip-1078.md) - 
This presents a method to replace the usual signup/login design pattern with a minimal ethereum native scheme, that doesn’t require passwords, backing up private keys nor typing seed phrases. 
* [ERC-1077 and ERC-1078: The magic of executable signed messages](https://ethereum-magicians.org/t/erc-1077-and-erc-1078-the-magic-of-executable-signed-messages-to-login-and-do-actions/351)
* [ERC-EIP on GitHub](/blockchain/ethereum/repositories/#erc-eip)

### ERC725-735 

* [ERC725](https://github.com/ethereum/EIPs/issues/725) 
  * The following describes standard functions for a unique identifiable proxy account to be used by humans, groups, organisations, objects and machines
* [ERC735](https://github.com/ethereum/EIPs/issues/735) -  The following describes standard functions for adding, removing and holding of claims.
  - These claims can attested from third parties (issuers) or self attested.
* [Origin partners on ERC725](https://coinjournal.net/origin-protocol-partners-on-new-erc-725-alliance-to-promote-the-adoption-of-blockchain-based-identity-standard)
* [Managing Identity with a UI—ERC-725](https://medium.com/originprotocol/managing-identity-with-a-ui-for-erc-725-5c7422b38c09)
* [Ethereum ERC725 Blockchain Based, Self-Sovereign Identity Management](https://bitcoinexchangeguide.com/ethereum-erc725-blockchain-based-self-sovereign-identity-management/)
* [erc725alliance.org](https://erc725alliance.org)

## Protocols
### Element

* [Introducing Element](https://medium.com/transmute-techtalk/introducing-element-328b4260e757)
  > Transmute is excited to announce Element, an implementation of the Sidetree Protocol on top of Ethereum and IPFS. This work was done in collaboration with Microsoft and Consensys under the Decentralized Identity Foundation (DIF)
  > ...
  > We’re excited to use the serviceEndpoints defined in Element DID documents to track external integrations, in a privacy preserving manner, including identity hubs, credential stores, and more. Furthermore, the scalability that Sidetree brings to DIDs is unprecedented.

<iframe width="560" height="315" src="https://www.youtube.com/embed/mk4w2tBTgdE" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

[on SSIMeetup](https://ssimeetup.org/element-did-method-sidetree-ethereum-ipfs-orie-steele-webinar-31/)

* [transmute-industries/sidetree.js](https://github.com/transmute-industries/sidetree.js)
  > Sidetree.js is an implementation of v0.1.0 of the sidetree specification

### Web3Modal

* [Web3Modal/web3modal](https://github.com/Web3Modal/web3modal)

> Web3Modal is an easy-to-use library to help developers add support for multiple providers in their apps with a simple customizable configuration.

> By default Web3Modal Library supports injected providers like (Metamask, Dapper, Gnosis Safe, Web3 Browsers, etc) and WalletConnect, You can also easily configure the library to support Portis, Fortmatic, Squarelink, Torus, Authereum, D'CENT Wallet and Arkane.


### Baseline

[twitter](https://twitter.com/baselineproto) - [docs](https://docs.baseline-protocol.org/) - [slack](https://communityinviter.com/apps/ethereum-baseline/join-us) - [tele](https://t.me/baselineprotocol) - [discord](https://discord.gg/NE8AYD7)

* [EY, ConsenSys, Microsoft unveil Baseline, a path for enterprises to public blockchain](https://www.ledgerinsights.com/baseline-protocol-ey-consensys-microsoft-enterprises-public-blockchain/)
  > This is early days for the protocol, with invitations to the community to help to build it out further. The protocol will be governed by the Ethereum-Oasis Project, managed by the open source OASIS community and funded by the Ethereum Foundation and the Enterprise Ethereum Alliance. The code has a very permissive license.
* [EY launches Baseline protocol, an open source initiative for the public Ethereum blockchain](https://www.ey.com/en_gl/news/2020/03/ey-launches-baseline-protocol-an-open-source-initiative-for-the-public-etherum-blockchain)
  > EY today announced the launch of the Baseline protocol, a new package of public domain blockchain tools that will allow enterprises to build and deploy procurement and other business processes securely and privately on the public Ethereum blockchain. EY developed the Baseline protocol in cooperation with ConsenSys and Microsoft.
* [Open source proof of concept shows how to privately and securely synchronize data and business logic between companies, using the Ethereum Mainnet](https://oasis-open-projects.org/open-source-proof-of-concept-ethereum-mainnet/)
  > May 21, 2020 – Today, the Baseline Protocol, an OASIS open source initiative, published a demo of multiple companies digitally managing purchase orders and volume discount agreements across disparate systems. The demo uses an approach called “baselining” to prevent data inconsistencies and workflow errors that often lead to problems in revenue recognition. 
* [ethereum-oasis/oasis-open-project](https://github.com/ethereum-oasis/oasis-open-project)
  > The Ethereum OASIS Open Project is an OASIS Open Project that exists to provide a neutral forum for diverse stakeholders to create high-quality specifications that facilitate Ethereum’s longevity, interoperability, and ease of integration. The Ethereum OASIS Project intends to develop clear, open standards, high-quality documentation, and shared test suites that facilitate new features and enhancements to the Ethereum protocol.
* [ethereum-oasis/baseline](https://github.com/ethereum-oasis/baseline)
  > The Baseline Protocol is an open source initiative that combines advances in cryptography, messaging, and blockchain to execute secure and private business processes at low cost via the public Ethereum Mainnet. The protocol will enable confidential and complex collaboration between enterprises without leaving any sensitive data on-chain 

### Ceramic

* [Introduction to the Ceramic Protocol](https://medium.com/ceramic/introduction-to-the-ceramic-protocol-8d56951ae3f)
  > For self-sovereign identity and to enable user-managed access control, 3Box uses Ceramic’s 3ID DID method which allows users to control their identity, information, and services using all of their existing private wallet keys.
* [Technical Specification](https://github.com/ceramicnetwork/ceramic/blob/master/SPECIFICATION.md)
* [ceramicnetwork/ceramic](https://github.com/ceramicnetwork/ceramic)
* [github.com/ceramicstudio](https://github.com/ceramicstudio)

## Companies

### 3box

[3box.io](https://3box.io/) - [Blog](https://medium.com/3box) - [GitHub](https://github.com/3box) - [twitter](https://twitter.com/3boxdb) - [discord](https://discord.gg/Z3f3Cxy)

- [Announcing Ethereum Profiles 1.0.0 is Live](https://medium.com/3box/announcing-ethereum-profiles-1-0-0-is-live-f0316e15ce23) - How to get started using 3Box profiles today 😄
  > Ethereum Profiles makes it simple for users to create a reusable profile for their Ethereum address which can easily be shared with dapps to simplify the onboarding experience and create a more frictionless, social web3 dapp ecosystem. Ethereum Profiles allows Ethereum users to collect and control their information on the distributed web using their existing Ethereum wallets.

### uPort

![](https://i.imgur.com/sPAP2g3.png)

* [uPort](https://www.uport.me/) [[**G**](https://github.com/uport-project/)] [[**T**](https://twitter.com/uport_me)]
   * [Ethereum studio ConsenSys launches digital IDs and assets secured on Ubuntu phones](http://www.ibtimes.co.uk/ethereum-studio-consensys-launches-internet-people-digital-ids-assets-secured-unbuntu-phones-1542620)
   * [Year in Review. What's to come in 2018](https://medium.com/uport/uport-year-in-review-whats-to-come-in-2018-15ccb9214439)
* [Different Approaches to Ethereum Identity Standards](https://medium.com/uport/different-approaches-to-ethereum-identity-standards-a09488347c87)
  ![](https://i.imgur.com/ASI0PaB.png)

* [uPort donates code to the Decentralized Identity Foundation](https://medium.com/decentralized-identity/uport-donates-code-to-the-decentralized-identity-foundation-349d4740acbd)

### Jolocom

![](https://i.imgur.com/BNmq1U9.png)

* [Jolocom](http://jolocom.com/) 
   * a "SmartWallet" for everyone to own their personal digital identity, using [Social Linked Data](https://github.com/solid/solid-spec), WebID, and verifiable claims standards via Ethereum smart contracts. 
   * [A universal identity layer we can only build together](https://stories.jolocom.com/a-universal-identity-layer-we-can-only-build-together-e297ed5ae4ed)

### Transmute

- [Transmute Industries](https://www.transmute.industries/)
  - [Introducing: Element](https://medium.com/transmute-techtalk/introducing-element-328b4260e757) - The Sidetree Protocol Implemented on Ethereum
  - [Encrypted Data Vaults](https://medium.com/transmute-techtalk/encrypted-data-vaults-c794055b170e)
  - [Verifiable Credentials with Transmute and Otaka](https://medium.com/transmute-techtalk/verifiable-credentials-with-transmute-and-okta-574edaec887b)


### Spidchain

![](https://i.imgur.com/azuC8lh.png)

* [Spidchain](http://www.spidchain.com/) [[**wp**](https://drive.google.com/file/d/0B89WE3IIHmy1Z0ZSSWVmVEtaaG8/view)]
   * "offers a platform for self-sovereign identity, including desktop and mobile apps for end-users. It uses Decentralized Identifiers (DIDs) - backed by optionally Bitcoin or Ethereum - to implement a marketplace for verifiable claims. The Spidchain applications allow individuals to create, recover, and revoke DIDs, to authenticate, to sign and verify files and claims, and more."
* [Spid-Eth GitHub Repos](/blockchain/ethereum/repositories/#spid-eth-repos)

### Cryptonomica

[![](https://i.imgur.com/moVyrrt.png)](https://cryptonomica.github.io)

 * [Cryptonomica.net](https://cryptonomica.net) is an identity verification service based on [OpenPGP](https://en.wikipedia.org/wiki/Pretty_Good_Privacy) and [Ethereum](https://www.ethereum.org) with legal framework and online dispute resolution for electronic contracts from London-based [court of arbitration](https://cryptonomica.net/#!/arbitration) 
  * [Cryptonomica Github Repos](/blockchain/ethereum/repositories/#cryptonomica)

### Assorted Applications

* [Deloitte SmartID](http://www.deloitte.co.uk/smartid/) [[**G**](https://github.com/SmartIdentity/smartId-contracts)]
   * "Smart Identity uses the Ethereum blockchain to represent an identity using a smart contract, attributes can be added by the identity owner and are stored in hash form"
* [Nuggets](http://www.nuggets.life/) [[**wp**](https://nuggets.life/images/Nuggets-White-Paper.pdf)]
   * "is a blockchain platform giving users a single biometric tool for login, payment and identity verification. It stores an individual's information in a "personal cloud" in "zero-knowledge blockchain storage".
* [poa.network](https://poa.network/) [[**D**](https://medium.com/poa-network/poa-network-how-honey-badger-bft-consensus-works-4b16c0f1ff94)]
 POA Network is an Ethereum-based platform that offers an open-source framework for smart contracts. POA Network is a sidechain to Ethereum utilizing [Proof of Authority](https://blockonomi.com/proof-of-authority/)
 as its consensus mechanism. 

## History 

* [Decentralized Digital Identity on Ethereum](https://www.slideshare.net/FabriceCroiseaux/ethcc-2018-decentralized-digital-identity-on-ethereum) -SlideShare
* [DEVCON1: Digital Identity](https://www.youtube.com/watch?v=QpaTOvAhLR4) — video from DEVCON1

<iframe src="//www.slideshare.net/slideshow/embed_code/key/e0yTGKpH8P3giS" width="595" height="485" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="border:1px solid #CCC; border-width:1px; margin-bottom:5px; max-width: 100%;" allowfullscreen> </iframe> <div style="margin-bottom:5px"> <strong> <a href="//www.slideshare.net/FabriceCroiseaux/ethcc-2018-decentralized-digital-identity-on-ethereum" title="EthCC 2018 - Decentralized Digital Identity on Ethereum" target="_blank">EthCC 2018 - Decentralized Digital Identity on Ethereum</a> </strong> from <strong><a href="https://www.slideshare.net/FabriceCroiseaux" target="_blank">Fabrice Croiseaux</a></strong> </div>

## ETC

* [Proof-of-Individuality](http://proofofindividuality.online/) — how to prove a person only has one account
   * [Anti-Sybil Protocol using virtual pseudonym parties](https://medium.com/@unlisted/anti-sybil-protocol-using-virtual-pseudonym-parties-10276fcf3b20)
* [EIDM: A Ethereum-Based Cloud User Identity Management Protocol](https://ieeexplore.ieee.org/document/8792212)
  > The new protocol is an improved version of CIDM (Consolidated Identity Management) referred to as EIDM (Ethrerum-based Identity Management) protocol. In the improved protocol, JWT (JSON Web Token) in OAuth 2.0 was used to introduce smart contracts into EIDM protocol, and the credit management system was added to the system so that it can provide a credible identity authentication protocol for cloud users and service providers. 
