---
title       : "Self Sovereign Identity (SSI)"
excerpt: >
  It would seem that Christopher Allen's The Path to Self-Sovereign Identity is still the most comprehensive introduction to the subject of Self Sovereign Identity. It outlines some of the underlying history, and introduces 10 Principles of Self-Sovereign Identity, born from the collective thoughts on identity leading to it.

  Considerable additional material has been created on the subject since then, including some helpful criticism on the principles. Some of initial thoughts have been organized in evolution-of-ssi.
description : Literature associated with the Fundamentals of Self-Sovereign Identity.
image       : "https://decentralized-id.com/images/sovereign-identity.png"
permalink: /literature/self-sovereign-identity/
canonical_url: 'https://decentralized-id.com/literature/self-sovereign-identity/'
redirect_from: 
  - /self-sovereign-identity
  - /self-sovereign-identity/
categories: ["Literature"]
tags: ["Self Sovereign Identity","Laws of Identity"]
last_modified_at: 2020-11-02
---

<center><img src="https://decentralized-id.com/images/sovereign-id-wide.png"/></center>

This directory was born from [WebOfTrustInfo/self-sovereign-identity](https://github.com/WebOfTrustInfo/self-sovereign-identity), *the original* SSI repository. 

It would seem that Christopher Allen's [The Path to Self-Sovereign Identity](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/ThePathToSelf-SovereignIdentity.md) is still the most comprehensive introduction to the subject of Self Sovereign Identity. It outlines some of the underlying history, and introduces [10 Principles of Self-Sovereign Identity](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/self-sovereign-identity-principles.md), born from the collective thoughts on identity leading to it.

Considerable additional material has been created on the subject since then, including some helpful criticism on the principles. Some of initial thoughts have been organized in [evolution-of-ssi](/literature/self-sovereign-identity/evolution-of-ssi/).

[![](https://i.imgur.com/S9uBk4k.png)](https://medium.com/@trbouma/self-sovereign-identity-an-unofficial-generic-icon-a5a6ab332cd7)

{% include video id="U8bZ4GYFwKY" provider="youtube" %}

## SSI Documentation Components

While none of this is authoritative, it's useful to keep in mind the philosophy an principles that have focused efforts around creating next generation digital identification schemes. 

* [The Path to Self-Sovereign Identity](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/ThePathToSelf-SovereignIdentity.md) - The original article on Self-Sovereign Identity and the 10 Principles of Self-Sovereign Identity as published on 2016-04-25 in github and at [Life With Alacrity](http://www.lifewithalacrity.com/2016/04/the-path-to-self-soverereign-identity.html) by [Christopher Allen](http://www.github.com/christophera) [[**ϟ**](https://www.coindesk.com/path-self-sovereign-identity/amp/)]
  * [10 Principles of Self-Sovereign Identity](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/self-sovereign-identity-principles.md) - The Self-Sovereign Identity Principles, in progress of being revised.
  * [Core Characteristics of Self Sovereign Identity](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/characteristics-of-sovereign-identity.md) - from *[A Technlogy-Free Definition of Self-Sovereign Identity](https://github.com/jandrieu/rebooting-the-web-of-trust-fall2016/raw/master/topics-and-advance-readings/a-technology-free-definition-of-self-sovereign-identity.pdf)* - Topic paper for Rebooting Web of Trust III by [Joe Andrieu](http://www.github.com/jandrieu) (for review and comparison against *10 Principles of SSI*)
    * [SSI Principles vs. Characteristics](/literature/self-sovereign-identity/ssi-principles-vs-characteristics/)
  * [Self-Sovereign Bill of Rights](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/self-sovereign-identity-bill-of-rights.md) - lifeID (founded by [Chris Boscolo](https://github.com/cboscolo)) adapted the 10 Principles of Self-Sovereign Identity into a [Bill of Rights](https://medium.com/@lifeID_io/lifeid-self-sovereign-identity-bill-of-rights-d2acafa1de8b) that all self-sovereign identity solution should uphold.
  * [Schutte's Take](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/Schutte-on-SSI.md) offers criticism on the 10 principles.
* [7 Myths of Self Sovereign Identity](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/7-myths-of-self-sovereign-identity.md) - from Timothy Ruff's [blog post](https://medium.com/evernym/7-myths-of-self-sovereign-identity-67aea7416b1).
* [A Gentle Guide to Self Sovereign Identity](https://bitsonblocks.net/2017/05/17/gentle-introduction-self-sovereign-identity/) has a section called "How would self-sovereign identity work for the user?" that could be [modularized](user-experience/).
* [How to Convince Dad* of the Importance of Self-Sovereign Identity](https://github.com/WebOfTrustInfo/rwot7/blob/master/final-documents/convincing-dad.md) (\*and your sister and your daughter and your best friend and your nephew) (SSI Use-Cases)
* [Self-Sovereign Identity and the Legitimacy of Permissioned Ledgers](http://www.windley.com/archives/2016/09/self-sovereign_identity_and_the_legitimacy_of_permissioned_ledgers.shtml)
* [HIPE 0014-ssi-notation](https://github.com/hyperledger/indy-hipe/tree/master/text/0014-ssi-notation)
* [SSI: A Roadmap for Adoption](https://github.com/WebOfTrustInfo/rebooting-the-web-of-trust-spring2018/blob/master/final-documents/a-roadmap-for-ssi.md) from Rebooting the web of trust, Spring 2018. 
  > This document proposes the formation of a short-term team to develop consistent messaging for the Self-Sovereign Identity (SSI) market.

![](https://imgur.com/3zz62kpl.png)

{% include video id="rygsE1JC-8Q" provider="youtube" %}
[What is self-sovereign identity? [Webinar]](https://www.youtube.com/watch?v=rygsE1JC-8Q)
  > - A brief history and overview of self-sovereign identity / decentralized identity
  > - The top consumer-focused and business-focused benefits of SSI
  > - Real-world examples of SSI in action
  > - How organizations can the journey to a decentralized future


### About SSI

* [Self-Sovereign Identity](https://thelivinglib.org/self-sovereign-identity/)
  > Identification document (ID) is a crucial part of every individual’s life, in that it is often a prerequisite for accessing a variety of services — ranging from creating a bank account to enrolling children in school to buying alcoholic beverages to signing up for an email account to voting in an election — and also a proof of simply being.
* [There’s A Facebook Alternative, It’s Called Self-Sovereign Identity](https://www.coindesk.com/theres-alternative-facebook-called-self-sovereign-identity) —coindesk
* [Self Sovereign Identity -identitywoman.net](https://identitywoman.net/self-sovereign-identity/)
* [Self Sovereign Identity going where no identity has gone before](https://www.brighttalk.com/webcast/16693/342423/self-sovereign-identity-going-where-no-identity-has-gone-before)
* [LESS identity](https://medium.com/@trbouma/less-identity-65f65d87f56b)
* [A Primer on Functional Identity](https://github.com/WebOfTrustInfo/rebooting-the-web-of-trust-fall2017/blob/master/topics-and-advance-readings/functional-identity-primer.md); Joe Andrieu describes identity terms in plain language, with regards to what function they serve.
* [karimStekelenburg/awesome-self-sovereign-identity](https://github.com/karimStekelenburg/awesome-self-sovereign-identity)
* [Identity and Digital Self-Sovereignty](https://medium.com/learning-machine-blog/identity-and-digital-self-sovereignty-1f3faab7d9e3) - Blog post by [Natalie Smolenski](https://medium.com/@nsmolenski)
* [Inevitable Rise of Self-Sovereign Identity](https://sovrin.org/wp-content/uploads/2018/03/The-Inevitable-Rise-of-Self-Sovereign-Identity.pdf)
* [The Three Models of Digital Identity Relationships — How self-sovereign identity (SSI) is different, and why it’s better](https://medium.com/evernym/the-three-models-of-digital-identity-relationships-ca0727cb5186) 
* [The Rise of Self-Sovereign Identity - Hyperledger Indy](https://wso2.com/blog/research/the-rise-of-self-sovereign-identity-hyperledger-indy)
* [Paving the Road to Self-Sovereign Identity with Blockchain, Open Standards](https://www.ibm.com/blogs/think/2017/10/self-sovereign-id-blockchain/)
* [The Nail Finds a Hammer: Self-Sovereign Identity, Design Principles, and Property Rights in the Developing World](https://www.newamerica.org/future-property-rights/reports/nail-finds-hammer/)
* [Self-Sovereign Privacy By Design](https://github.com/sovrin-foundation/protocol/blob/master/self_sovereign_privacy_by_design_v1.md)
* [Self-sovereign Identity –	Opportunities and Challenges for the Digital Revolution](https://arxiv.org/pdf/1712.01767.pdf)
* [Decentralized Identity Trilemma](http://maciek.blog/DecentralizedIDentity-trilemma/)
   >There seems to exist a trilemma in decentralized identity analogous to @Zooko's triangle. None of the existing solutions are at the same time: 1) privacy-preserving, 2) Sybil-resistant 3) self-sovereign -[[**T**](https://twitter.com/MaciekLaskus/status/1031859093072424960)]
* [Self Sovereign Identity and MyData](https://medium.com/@apoikola/self-sovereign-identity-and-mydata-e1f996a9451)
* [IIW - Past Workshops](https://internetidentityworkshop.com/past-workshops/)
* [Matching Identity Management Solutions to Self Sovereign Identity Solutions](https://www.slideshare.net/TommyKoens/matching-identity-management-solutions-to-selfsovereign-identity-principles)
* [A Brief Introduction to How SSI Infrastructure Can Integrate Digital Fiat Currency (DFC)](https://www.itu.int/en/ITU-T/Workshops-and-Seminars/20180718/Documents/D_Reed.pdf)
* [![](https://i.imgur.com/tNvN7vV.png)](https://twitter.com/VitalikButerin/status/1072160446180810752)

[![](https://i.imgur.com/f3FlznM.png)](https://twitter.com/ChristopherA/status/989120215702261761?ref_src=twsrc%5Etfw)

[The Three Pillars of Self-Sovereign Identity](https://www.evernym.com/blog/the-three-pillars-of-self-sovereign-identity/)
[Self-sovereign identity: 3 key questions](https://www.csoonline.com/article/3366261/self-sovereign-identity-3-key-questions.html)
  > SSI is on the extreme end of the digital identity spectrum. Its focus is putting control back in the hands of you, the user. But SSI is not the only way to skin a cat.
[Answering Questions about Self-Sovereign Identity](https://www.windley.com/archives/2019/07/answering_questions_about_self-sovereign_identity.shtml)
  > Identity professionals continue to have questions about self-sovereign identity (SSI). In this post, I answer a few questions that Susan Morrow raised about the commercial viability, security, privacy, and desired user experience of SSI.

![](https://i.imgur.com/MMa72Dx.png)

[Self-Sovereign Identity: Shifting the Locus of Control](https://medium.com/@trbouma/self-sovereign-identity-shifting-the-locus-of-control-10da1c8757ad)
  > Simply put, the old (centralized and federated models) the locus of control was between the other parties that could make decisions about me, whether I was in the picture or not. In the new model (self-sovereign identity), the user is put into the centre of his/her own locus of control. See above.
 

#### Video

* [Identity and the quest for Self Sovereign Identity - Daniel Hardman](https://www.youtube.com/watch?v=iqmY_h49vPs)
* [Self Sovereign Identity and the MyData model from Finland - Antti 'Jogi' Poikola](https://www.youtube.com/watch?v=amq88XmWaNs)
* [Self-Sovereign Identity (SSI) and Open Source – Richard Esplin from SSIMeetup](http://ssimeetup.org/self-sovereign-identity-ssi-open-source-richard-esplin-webinar-16/)
* [Decentralized Identifiers enable self-sovereign identity - MyData 2018](https://www.youtube.com/watch?v=KsIM0zq37fU)
* [eIDAS and Self-Sovereign Identity - MyData 2018](https://www.youtube.com/watch?v=AHa175AEVVs)
* [uPort: Self-Sovereign Identity Meets Portable Data](https://www.youtube.com/watch?v=hBIragrwqYc)
* [Behind the Cloud—Blockchain and Self-Sovereign Identity in the Enterprise](https://www.youtube.com/watch?v=wSdm2-18Z2g)
* [The Story of Open SSI Standards - Drummond Reed](https://www.youtube.com/watch?v=RllH91rcFdE&feature=youtu.be&t=4m30s)

### History

* [Kim Cameron Identity Laws](https://channel9.msdn.com/Blogs/scobleizer/Kim-Cameron-Identity-Laws)
  * [Laws of Identity - Whitepaper](https://web.archive.org/web/20080814163727/http://www.identityblog.com/stories/2004/12/09/thelaws.html)
*  [*What is Sovereign Source Authority?*](https://www.moxytongue.com/2012/02/what-is-sovereign-source-authority.html) shows an early use of 'sovereign' in relation to our internet identities. The term "Self Sovereign Identity" started becoming widely used in 2014.[[**ϟ**](https://www.tokencommons.org/Windhover-Principles-for-Digital-Identity-Trust-Data.html)][[**ϟ**](https://hubculture.com/hubs/47/news/689/)]
* [Sovrin Foundation Launches first dedicated Self Sovereign Identity Network](https://www.prnewswire.com/news-releases/sovrin-foundation-launches-first-dedicated-self-sovereign-identity-network-300336702.html) 

### Resources

* [SSIMeetup](http://ssimeetup.org/) [[Slideshare](https://www.slideshare.net/SSIMeetup/presentations)] [[Youtube](https://www.youtube.com/channel/UCSqSTlKdbbCM1muGOhDa3Og)] [[Telegram](https://t.me/SSIMeetup)] - SSI Meetup is an open, collaborative community to help SSI evangelists around the world, independent of company interests or standards. 
* [WebOfTrustInfo/self-sovereign-id](https://github.com/WebOfTrustInfo/self-sovereign-identity)
* [Self-Sovereign Identity — wiki.p2pfoundation](https://wiki.p2pfoundation.net/Self-Sovereign_Identity)



