---
date: 2020-01-07
title: Hyperledger Aries
excerpt: >
  One of the architectural components of Indy is called an Agent. This is software that acts on behalf of an identity owner to communicate off-ledger with other Agents. As Agent work continued with the development of message encryption standards, extensible message typing, and common protocols, interest grew in applying these concepts and practices to systems based on other ledgers. It became clear that the right future for Agent work was to e-xtract it from Indy project and add support for other ledger technologies to make that integration easier and more powerful. That work is now known as Hyperledger Aries.
categories: ["Hyperledger Foundation"]
tags: ["Aries"]
permalink: organizations/hyperledger/aries/
redirect_from: 
  - hyperledger/aries/
last_modified_at: 2020-01-07
---

[Announcing Hyperledger Aries, infrastructure supporting interoperable identity solutions!](https://www.hyperledger.org/blog/2019/05/14/announcing-hyperledger-aries-infrastructure-supporting-interoperable-identity-solutions)
  > Identity is commonly cited as one of the most promising use-cases for distributed ledger technology. Initiatives and solutions focused on creating, transmitting and storing verifiable digital credentials will benefit from a shared, reusable, interoperable tool kit. Hyperledger Aries, the newest Hyperledger project (the13th!), is a shared infrastructure of tools that enables the exchange of blockchain-based data, supports peer-to-peer messaging in various scenarios, and facilitates interoperable interaction between different blockchains and other distributed ledger technologies (DLTs).

[Hyperledger Aries: The Next Major Step Towards Interoperable SSI](https://www.evernym.com/blog/hyperledger-aries/)
  > Aries was born out of the work on identity agents and identity wallets that began in the Hyperledger Indy project. As a company focused entirely on decentralized identity, Evernym was one of the original founders of the Sovrin Network and contributed the first code to the open source project Hyperledger Indy.

[Hyperledger Aries: Open Source Interoperable Identity Solution – Nathan George – Webinar 30](https://ssimeetup.org/hyperledger-aries-open-source-interoperable-identity-solutions-nathan-george-webinar-30/)
  > Aries will be the industry’s first implementation of interoperable open source wallets for digital credentials that use the DKMS (Decentralized Key Management System) architecture that Evernym pioneered under a contract with the U.S. Department of Homeland Security.


{% include video id="PXPZQB3VG9w" provider="youtube" %}


[Sovrin proudly contributes to Hyperledger Aries](https://sovrin.org/sovrin-proudly-contributes-to-hyperledger-aries/)
  > One of the architectural components of Indy is called an Agent. This is software that acts on behalf of an identity owner to communicate off-ledger with other Agents. As Agent work continued with the development of message encryption standards, extensible message typing, and common protocols, interest grew in applying these concepts and practices to systems based on other ledgers. It became clear that the right future for Agent work was to e-xtract it from Indy project and add support for other ledger technologies to make that integration easier and more powerful. That work is now known as Hyperledger Aries.
  >
  > In addition to being able to support more ledger technologies than just Indy, Aries can work with multiple ledgers at the same time. This allows Agents to use each ledger according to the unique power offered by each, instead of requiring anchoring to only one ledger. In the future, Agents will be able to integrate not only with the recently announced Ion DID method, but also Ethereum, Hyperledger Sawtooth, Bitcoin, Hyperledger Fabric, and others.

[![](https://imgur.com/CEwJAEgl.png)](https://www.slideshare.net/SSIMeetup/hyperledger-aries-open-source-interoperable-identity-solution-nathan-george)

[Hyperledger Aries to Enable Blockchain-Agnostic, Self-Sovereign Identity](https://medium.com/@xragrawal/hyperledger-aries-to-enable-blockchain-agnostic-self-sovereign-identity-a7d523064112)
  > In two years since the introduction of Hyperledger Indy in 2017, the scope of work within its development community has far extended beyond what was initially set in its proposal. To clarify and keep track of new and existing peer-to-peer interaction code for secrets management, verifiable information exchange, and secure messaging across different blockchains and other distributed ledger technologies, Hyperledger Aries was set in motion.

[The VON IIW 28 Demonstration: IIWBook](https://vonx.io/how_to/iiwbook)
  > In late March 2019, the VON team created AgentBook to demonstrate the interoperability of independently created agents. These agents were able to successfully establish DID-based communication channels. Now, with IIWBook, we’ve added a (literal) new layer by extending the core of AgentBook with the ability to exchange verifiable credentials. Even more exciting, through collaboration with Streetcred and Spark New Zealand, we have a mobile agent (or two!).

## Code \ Documentation

[hyperledger/indy-hipe/text/0002-agents](https://github.com/hyperledger/indy-hipe/tree/master/text/0002-agents)
  > - A mobile app that Alice uses to manage credentials and to connect to others is an agent for Alice.
  > 
  > - A cloud-based service that Alice uses to expose a stable endpoint where other agents can talk to her is an agent for Alice.
  > 
  > - A server run by Faber College, allowing it to issue credentials to its students, is an agent for Faber.
  > 
  > Having a tight definition of an agent may not matter in all cases. However, it is important when we are trying to understand interoperability goals. We want agents to be able to interact with one another. Does that mean they must interact with every piece of software that is even marginally agent-like? Probably not.
  > 
  >
  > Some attributes that are not technically necessary in agents include...

[Aries Cloud Agent Python Code Documentation](https://aries-cloud-agent-python.readthedocs.io/en/latest/)
  > Hyperledger Aries Cloud Agent Python (ACA-Py) is a foundation for building decentralized identity applications and services running in non-mobile environments.
  > 
  > This is the Read The Docs site for the Hyperledger Aries Cloud Agent Python. This site contains only the ACA-Py docstrings documentation extracted from the Python Code. For other documentation, please consult the links in the Readme for the ACA-Py GitHub Repo.

[@TelegramSam](https://github.com/TelegramSam?tab=repositories)'s Aries repositories
* [hyperledger/aries](https://github.com/hyperledger/aries)
  > Hyperledger Aries is infrastructure for blockchain-rooted, peer-to-peer interactions
* [hyperledger/aries-rfcs](https://github.com/hyperledger/aries-rfcs)
* [aries-toolbox](https://github.com/TelegramSam/aries-toolbox) - tool for interacting with Agents
* [hyperledger/aries-cloudagent-python](https://github.com/hyperledger/aries-cloudagent-python)
  > Hyperledger Aries Cloud Agent Python (ACA-Py) is a foundation for building decentralized identity applications and services running in non-mobile environments.
    * [hyperledger/aries-cloudagent-python/docs/GettingStartedAriesDev/](https://github.com/hyperledger/aries-cloudagent-python/blob/master/docs/GettingStartedAriesDev/README.md)
      > Hyperledger Aries Cloud Agent Python (ACA-Py) is a foundation for building decentralized identity applications and services running in non-mobile environments.
* [hyperledger/aries-acapy-plugin-toolbox](https://github.com/hyperledger/aries-acapy-plugin-toolbox)
  > Aries Cloud Agent - Python plugin for the Aries Toolbox
* [hyperledger/aries-protocol-test-suite](https://github.com/hyperledger/aries-protocol-test-suite)
  > Test Suite for testing protocol compliance of Aries Agents
* [hyperledger/aries-staticagent-python](https://github.com/hyperledger/aries-staticagent-python)
* [hyperledger/aries-sdk-python](https://github.com/hyperledger/aries-sdk-python)
* [hyperledger/aries-agent](https://github.com/hyperledger/aries-agent)
  > Hyperledger Aries is infrastructure for blockchain-rooted, peer-to-peer interactions
