---
date: 2020-01-04
title: JSON-LD
excerpt: >
  The Semantic Web isn't just about putting data on the web. It is about making links, so that a person or machine can explore the web of data.  With linked data, when you have some of it, you can find other, related, data.
   
  Like the web of hypertext, the web of data is constructed with documents on the web. However,  unlike the web of hypertext,  where links are relationships anchors in hypertext documents written in HTML, for data they links  between arbitrary things described by RDF,.  The URIs identify any kind of object or  concept.
layout: single
permalink: /web-standards/linked-data/JSON-LD/
redirect_from: 
  - /specs-standards/JSON-LD/
  - /specs-standards/linked-data/JSON-LD/
canonical_url: 'https://decentralized-id.com/specs-standards/linked-data/JSON-LD/'
categories: ["Web Standards"]
tags: ["Digital Bazaar","JSON-LD","Credentials Community Group","Veres One", "Linked Data"]
last_modified_at: 2020-01-09
---

## 101

* [JSON-LD for Beginners](https://moz.com/blog/json-ld-for-beginners)
* [Why JSON-LD](https://jsonld.com/why-json-ld/)
  > JSON-LD is able to accomplish the same thing, but does not require HTML. It can exist in and of itself. In short, JSON-LD can be inserted into your web page without disrupting the current content or HTML.

## NFO

* [On JSON-LD and the semantics of Identity](https://medium.com/transmute-techtalk/on-json-ld-and-the-semantics-of-identity-42d051d3ce14) Orie Steele
  > In this post, we’ll explore how JSON-LD is used in a number of contexts including decentralized identity and verifiable credentials. We’ll also cover the basics of what you should know before using JSON-LD and how you can contribute to software and standards that rely on it.
* [Publishing JSON-LD for Developers](https://datalanguage.com/news/publishing-json-ld-for-developers) - [Hacker News](https://news.ycombinator.com/item?id=17021939)
* [What Is JSON-LD Markup and Why Is It Better than Schema.org?](https://sitechecker.pro/json-ld-markup/)
  > If you understand how to use schema.org, but do not dare to mark pages up because of the complexity of the process, this article is for you. There is an effective and easy-to-use alternative - the JSON-LD format.
* [‎Libre Lounge: Episode 17: ActivityPub Part 2 on Apple Podcasts](https://librelounge.org/episodes/episode-17-activitypub-part-2.html) - [Part 1](https://librelounge.org/episodes/episode-12-activitypub-part-1.html) - [Part 3](https://librelounge.org/episodes/episode-20-activitypub-part-3.html)
  > In our ongoing series about ActivityPub, Chris and Serge explore the world of JSON-LD and the ActivityStreams vocabulary.
  > 
  > Links: [ActivityPub Specification (w3c)](https://www.w3.org/TR/activitypub/) - [ActivityStreams (w3c)](https://www.w3.org/TR/activitystreams-core/) - [JSON-LD (json-ld.org)](https://json-ld.org/) [JSON-LD Playground (json-ld.org)](https://json-ld.org/playground/) - [Cyc (wikipedia)](https://en.wikipedia.org/wiki/Cyc) - [RDF (w3c)](https://www.w3.org/RDF/)
* [JSON-LD and Why I Hate the Semantic Web](http://manu.sporny.org/2014/json-ld-origins-2/) - [Hacker News](https://news.ycombinator.com/item?id=14474222)


## [JSON-LD Articles and Presentations](https://json-ld.org/learn.html) ([source](https://github.com/json-ld/json-ld.org))

### Introductory Material

- [What is Linked Data?](http://www.youtube.com/watch?v=4x_xzT5eF5Q) Short video introduction to Linked Data by Manu Sporny.
- [What is JSON-LD?](http://www.youtube.com/watch?v=vioCbTo3C-4) Short video introduction to JSON-LD by Manu Sporny.
- [JSON-LD: Core Markup](https://www.youtube.com/watch?v=UmvWk_TQ30A) An overview of some of the core markup features of JSON-LD including types, aliasing, nesting, and internationalization support by Manu Sporny.
- [JSON-LD: Compaction and Expansion](https://www.youtube.com/watch?v=Tm3fD89dqRE) An overview of JSON-LD's compaction and expansion features and how you can use them to merge data from multiple sources by Manu Sporny.
- [Linked Data Signatures](https://www.youtube.com/watch?v=QdUZaYeQblY) An overview of how digital signatures can be added to Linked Data to provide verifiable statements on the Web by Manu Sporny.
- [Credentials on the Web](https://www.youtube.com/watch?v=eWtOg3vSzxI) A quick introduction to verifiable credentials on the Web by Manu Sporny.
- [Creating 3rd Generation Web APIs with JSON-LD and Hydra](http://m.lanthi.com/www2013-paper), Markus Lanthaler. Proceedings of the Proceedings of the 22nd International World Wide Web Conference (WWW2013), pp. 35-37. Rio de Janeiro, Brazil: ACM Press.
- [Model Your Application Domain, Not Your JSON Structures](http://m.lanthi.com/wsrest2013-paper), Markus Lanthaler and Christian Gütl. Proceedings of the 4th International Workshop on RESTful Design (WS-REST 2013) at WWW2013, pp. 1415-1420. Rio de Janeiro, Brazil: ACM Press.
- [Hydra: A Vocabulary for Hypermedia-Driven Web APIs](http://m.lanthi.com/ldow2013-paper), Markus Lanthaler and Christian Gütl. Proceedings of the 6th Workshop on Linked Data on the Web (LDOW2013) at WWW2012. Rio de Janeiro.
- [On Using JSON-LD to Create Evolvable RESTful Services](http://m.lanthi.com/jsonld4rest-paper), Markus Lanthaler and Christian Gütl. Proceedings of the 3rd International Workshop on RESTful Design (WS-REST 2012) at WWW2012, pp. 25-32. Lyon, France: ACM Press.

### Presentations

- [JSON-LD: JSON for the Social Web](http://www.slideshare.net/gkellogg1/jsonld-json-for-the-social-web) by Gregg Kellogg, W3C Social Standards Workshop 2013, San Francisco, CA, USA.
- [Building Next-Generation Web APIs with JSON-LD and Hydra](http://slidesha.re/sl-portland2013) by Markus Lanthaler, Symfony Live Portland 2013, OR, USA.
- [Model Your Application Domain, Not Your JSON Structures](http://slidesha.re/wsrest2013-preso) by Markus Lanthaler, World Wide Web Conference (WWW2013), Rio de Janeiro, Brazil.
- [Hydra: A Vocabulary for Hypermedia-Driven Web APIs](http://slidesha.re/ldow2013-preso) by Markus Lanthaler, World Wide Web Conference (WWW2013), Rio de Janeiro, Brazil.
- [JSON-LD: JSON for Linked Data](http://www.slideshare.net/gkellogg1/json-for-linked-data) by Gregg Kellogg, Semantic Technology & Business Conference (SemTechBiz SF 2012), San Francisco, CA, USA.
- [JSON-LD for RESTful Services](http://slidesha.re/jsonld4rest) by Markus Lanthaler, World Wide Web Conference (WWW2012), Lyon, France.
- [JSON-LD and MongoDB](http://www.slideshare.net/gkellogg1/jsonld-and-mongodb) by Gregg Kellogg, NoSQL Now! 2012, San Jose, CA, USA.
- [JSON-LD Update – DC-2017](http://www.greggkellogg.net/presentations/JSON-LD-Update-DC-2017/) by Gregg Kellogg, DC 2017, October 2017, Washington DC.
- [JSON-LD Update – W3C TPAC 2017](https://json-ld.org/presentations/JSON-LD-Update-TPAC-2017/) by Gregg Kellogg, October 2017, Washington DC.
- [JSON-LD Support for Property Graphs – W3C Data Workshop](https://json-ld.org/presentations/JSON-LD-Support-for-Property-Graphs/) by Gregg Kellogg, May 2019, Berlin.
- [JSON-LD Update – W3C TPAC 2019](https://json-ld.org/presentations/JSON-LD-Update-TPAC-2019/) by Gregg Kellogg, September 2019, Fukuoka, Japan.

### Blog Posts

- [JSON-LD: Building Meaningful Data APIs](http://blog.codeship.com/json-ld-building-meaningful-data-apis/), [Benjamin Young](http://bigbluehat.com/).
- [Webizing your database with Linked Data in JSON-LD on Cloudant](https://cloudant.com/blog/webizing-your-database-with-linked-data-in-json-ld/), [Benjamin Young](http://bigbluehat.com/).

Website content released under a [Creative Commons CC0 Public Domain Dedication](http://creativecommons.org/about/cc0) except where an alternate is specified. Part of the [PaySwarm](http://payswarm.com/) standardization initiative.

## GitHub Repositories

* [Torann/json-ld](https://github.com/Torann/json-ld) - Extremely simple JSON-LD Generator
* [piprate/json-gold](https://github.com/piprate/json-gold) - JSON-goLD Documentations Travis CI results GoCover.io
  > This library is an implementation of the JSON-LD 1.1 specification in Go. It supports both URDNA2015 and URGNA2012 RDF dataset normalisation algorithms.
* [JayHoltslander/Structured-Data-JSON-LD](https://github.com/JayHoltslander/Structured-Data-JSON-LD)
  > Collection of structured data snippets in Google preferred JSON-LD format. [codepen.io/collection/DNvPJE/](https://codepen.io/collection/DNvPJE/)
* [codemeta/codemeta](https://github.com/codemeta/codemeta)
  > CodeMeta contributors are creating a minimal metadata schema for science software and code, in JSON and XML. The goal of CodeMeta is to create a concept vocabulary that can be used to standardize the exchange of software metadata across repositories and organizations. CodeMeta started by comparing the software metadata used across multiple repositories, which resulted in the CodeMeta Metadata Crosswalk. That crosswalk was then used to generate a set of software metadata concepts, which were arranged into a JSON-LD context for serialization.

### [JSON-LD WG](https://www.w3.org/2018/json-ld-wg/)
- [w3c/json-ld-framing](https://github.com/w3c/json-ld-framing) - JSON-LD 1.1 Framing Specification
- [w3c/json-ld-api](https://github.com/w3c/json-ld-api) - JSON-LD 1.1 Processing Algorithms and API Specification
- [w3c/json-ld-syntax](https://github.com/w3c/json-ld-syntax) - JSON-LD 1.1 Specification
* [w3c/json-ld-bp](https://github.com/w3c/json-ld-bp) JSON-LD 1.1 Best Practices Note [w3c.github.io/json-ld-bp](https://w3c.github.io/json-ld-bp/)
* [w3c/json-ld-rc](https://github.com/w3c/json-ld-rc)

## JSON-LD Public Repositories 
* [json-ld/json-ld.org](https://github.com/json-ld/json-ld.org) - JSON for Linked Data
* [json-ld/json-ld-patch](https://github.com/json-ld/json-ld-patch) - JSON-LD Patch
* [json-ld/minutes](https://github.com/json-ld/minutes) - Teleconference minutes - text and audio logs
* [json-ld/normalization](https://github.com/json-ld/normalization) - RDF Dataset Normalization
* [json-ld/tests](https://github.com/json-ld/tests) Archived - [READ-ONLY] Subtree split of the JSON-LD tests – obsolete, please see WG test suites
* [json-ld/scrawl.js](https://github.com/json-ld/scrawl.js)
Scribe tool used by the JSON-LD Community Group
* [json-ld/Charter](https://github.com/json-ld/Charter)
Charter for JSON-LD WG

### Digital Bazaar
- [json-ld](https://github.com/digitalbazaar/json-ld) - A Context-based JSON Serialization for Linked Data
- [jsonld-cli](https://github.com/digitalbazaar/jsonld-cli) - JSON-LD command line interface tool
- [pyld](https://github.com/digitalbazaar/pyld) - JSON-LD processor written in Python
- [jsonld.js](https://github.com/digitalbazaar/jsonld.js) - A JSON-LD Processor and API implementation in JavaScript
- [php-json-ld](https://github.com/digitalbazaar/php-json-ld) - PHP implementation of a JSON-LD Processor and API
- [jsonld-signatures](https://github.com/digitalbazaar/jsonld-signatures) - An implementation of the Linked Data Signatures specification for JSON-LD. Works in the browser and Node.js.
- [jsonld-request](https://github.com/digitalbazaar/jsonld-request) - LIbrary to load JSON-LD from stdin, URLs, or files.
- [jsonld-patch](https://github.com/digitalbazaar/jsonld-patch) - JSON patch for JSON-LD
- [crypto-ld](https://github.com/digitalbazaar/crypto-ld)
- [ecdsa-koblitz-signature-2016](https://github.com/digitalbazaar/ecdsa-koblitz-signature-2016) - Provides EcdsaKoblitzSignature2016 LD proof suite
- [bedrock-angular-jsonld](https://github.com/digitalbazaar/bedrock-angular-jsonld) - JSON-LD support for bedrock-angular apps
- [cuckoo-ldp](https://github.com/digitalbazaar/cuckoo-ldp) - Cuckoo Cycle Based Linked Data Proofs
- [proofs-ld](https://github.com/digitalbazaar/proofs-ld)
- [ld-signature-demo](https://github.com/digitalbazaar/ld-signature-demo)
- [bedrock-angular-ldn](https://github.com/digitalbazaar/bedrock-angular-ldn) - Bedrock AngularJS module for Linked Data Notification Sender+Consumer
- [bedrock-ldn-inbox](https://github.com/digitalbazaar/bedrock-ldn-inbox) - Bedrock module for Linked Data Notification Inboxes
- [bedrock-ldn-receiver](https://github.com/digitalbazaar/bedrock-ldn-receiver) - Bedrock module for Linked Data Notification Receiver
- [x25519-key-pair](https://github.com/digitalbazaar/x25519-key-pair) - An X25519 (Curve25519) DH key implementation to work with the crypto-ld LDKeyPair API


